85a7688f63357ea593b2d93fb5b9ccefb215f3a3
max
  Wed Jan 27 10:53:36 2016 -0800
renaming malacards.c to malaCards.c by email from Jim. Also changing the
comments but not the table name, as it has already been pushed to the RR. no redmine.

diff --git src/hg/hgGene/hgGene.h src/hg/hgGene/hgGene.h
index cec177b..efb7e05 100644
--- src/hg/hgGene/hgGene.h
+++ src/hg/hgGene/hgGene.h
@@ -118,33 +118,33 @@
 	struct hash *sectionRa);
 /* Create altSplice section. */
 
 struct section *ctdSection(struct sqlConnection *conn, 
 	struct hash *sectionRa);
 /* Create CTD section. */
 
 struct section *ctdRgdGene2Section(struct sqlConnection *conn, 
 	struct hash *sectionRa);
 /* Create CTD section. */
 
 struct section *gadSection(struct sqlConnection *conn, 
 	struct hash *sectionRa);
 /* Create GAD section. */
 
-struct section *malacardsSection(struct sqlConnection *conn, 
+struct section *malaCardsSection(struct sqlConnection *conn, 
 	struct hash *sectionRa);
 /* Create malacards section. */
 
 struct section *domainsSection(struct sqlConnection *conn, 
 	struct hash *sectionRa);
@@ -118,33 +118,33 @@
 	struct hash *sectionRa);
-/* Create malacards section. */
+/* Create malaCards section. */
 
 struct section *domainsSection(struct sqlConnection *conn, 
 /* Create domains section. */
 
 struct section *pathwaysSection(struct sqlConnection *conn, 
 	struct hash *sectionRa);
 /* Create pathways section. */
 
 struct section *rnaStructureSection(struct sqlConnection *conn,
 	struct hash *sectionRa);
 /* Create rnaStructure section. */
 
 struct section *localizationSection(struct sqlConnection *conn,
 	struct hash *sectionRa);